@@ -16,6 +16,7 @@
 */
 
 #include "volumefadereffect.h"
+
 #include "debug.h"
 
 #include <gst/gstbin.h>
@@ -24,8 +25,6 @@
 
 #include <QtCore/QTimeLine>
 
-QT_BEGIN_NAMESPACE
-
 #ifndef QT_NO_PHONON_VOLUMEFADEREFFECT
 namespace Phonon
 {
@@ -37,9 +36,12 @@ VolumeFaderEffect::VolumeFaderEffect(Backend *backend, QObject *parent)
     , m_fadeFromVolume(0)
     , m_fadeToVolume(0)
 {
-    m_effectElement = gst_element_factory_make ("volume", NULL);
-    if (m_effectElement)
+    GstElement *effectElement = gst_element_factory_make("volume", NULL);
+    if (effectElement) {
+        setEffectElement(effectElement);
         init();
+    }
+
     m_fadeTimeline = new QTimeLine(1000, this);
     connect(m_fadeTimeline, SIGNAL(valueChanged(qreal)), this, SLOT(slotSetVolume(qreal)));
 }
@@ -53,31 +55,32 @@ GstElement* VolumeFaderEffect::createEffectBin()
     GstElement *audioBin = gst_bin_new(NULL);
 
     // We need a queue to handle tee-connections from parent node
-    GstElement *queue= gst_element_factory_make ("queue", NULL);
+    GstElement *queue = gst_element_factory_make("queue", NULL);
     gst_bin_add(GST_BIN(audioBin), queue);
 
-    GstElement *mconv= gst_element_factory_make ("audioconvert", NULL);
+    GstElement *mconv = gst_element_factory_make("audioconvert", NULL);
     gst_bin_add(GST_BIN(audioBin), mconv);
-    gst_bin_add(GST_BIN(audioBin), m_effectElement);
+    gst_bin_add(GST_BIN(audioBin), effectElement());
 
     // Link src pad
-    GstPad *srcPad= gst_element_get_static_pad (m_effectElement, "src");
-    gst_element_add_pad (audioBin, gst_ghost_pad_new ("src", srcPad));
-    gst_object_unref (srcPad);
+    GstPad *srcPad = gst_element_get_static_pad(effectElement(), "src");
+    gst_element_add_pad(audioBin, gst_ghost_pad_new("src", srcPad));
+    gst_object_unref(srcPad);
 
     // Link sink pad
-    gst_element_link_many(queue, mconv, m_effectElement, NULL);
-    GstPad *sinkpad = gst_element_get_static_pad (queue, "sink");
-    gst_element_add_pad (audioBin, gst_ghost_pad_new ("sink", sinkpad));
-    gst_object_unref (sinkpad);
+    gst_element_link_many(queue, mconv, effectElement(), NULL);
+    GstPad *sinkpad = gst_element_get_static_pad(queue, "sink");
+    gst_element_add_pad(audioBin, gst_ghost_pad_new("sink", sinkpad));
+    gst_object_unref(sinkpad);
     return audioBin;
 }
 
 float VolumeFaderEffect::volume() const
 {
     gdouble val = 1.0;
-    if (m_effectElement)
-        g_object_get(G_OBJECT(m_effectElement), "volume", &val, NULL);
+    if (effectElement()) {
+        g_object_get(G_OBJECT(effectElement()), "volume", &val, NULL);
+    }
     return (float)val;
 }
 
@@ -117,7 +120,7 @@ void VolumeFaderEffect::fadeTo(float targetVolume, int fadeTime)
 {
     abortFade();
     m_fadeToVolume = targetVolume;
-    g_object_get(G_OBJECT(m_effectElement), "volume", &m_fadeFromVolume, NULL);
+    g_object_get(G_OBJECT(effectElement()), "volume", &m_fadeFromVolume, NULL);
 
     // Don't call QTimeLine::setDuration() with zero.
     // It is not supported and breaks fading.
@@ -143,12 +146,10 @@ void VolumeFaderEffect::abortFade()
 
 void VolumeFaderEffect::setVolumeInternal(float v)
 {
-    g_object_set(G_OBJECT(m_effectElement), "volume", (gdouble)v, NULL);
+    g_object_set(G_OBJECT(effectElement()), "volume", (gdouble)v, NULL);
     debug() << "Fading to" << v;
 }
 
 }} //namespace Phonon::Gstreamer
 #endif //QT_NO_PHONON_VOLUMEFADEREFFECT
-QT_END_NAMESPACE
-
 #include "moc_volumefadereffect.cpp"
